function [F, d] = compan(coefs, nlags)
% PURPOSE: Create the companion matrix for a univariate process with
% coefficients arcoefs. The matrix will define nlags lags, which is
% possibly more lags than in the arcoefs.
% INPUTS: 
% coefs - [c rho1 ...] - AR coefficients starting with the constant
% nlags - number of lags, possibly larger than the number of lags of the AR
%         process
if isempty(coefs)
    F = []; d = []; return
end
nar = length(coefs)-1;
N = max(nar, nlags);
% companion matrix
F = zeros(N,N);
F(1,1:nar) = coefs(2:end)';
F(2:end,1:end-1) = eye(N-1);
% constant term
d = zeros(N,1); d(1) = coefs(1);
end
