function [b, sig2, logpriorbsig2] = drawbsig2(y, X, sig2, priorm, priorvar, priors, priorv)
% PURPOSE: Draw coefficient vector b and error variance sig2 of a linear
% regression:     y = X*b + u, u~N(0,sig2)
% prior: p(b) = N(priorm, priorvar), p(sig2) = IG2(priors, priorv), indep.
% Evaluate the prior at the drawn point (b,sig2).
% This function is intended to be called as a part of a Gibbs sampler:
% - the draw of b is conditional on the supplied sig2.
% - the draw of sig2 is conditional on the draw of b.

[T, N] = size(X);

% draw b
Vpost = inv(inv(priorvar) + X'*X./sig2);
b = Vpost*(priorvar\priorm + X'*y./sig2) + chol(Vpost)'*randn(N,1);

% draw sig2
u = y - X*b;
s = priors + sum(u.^2);
temp = randn(priorv + T, 1);
sig2 = s / sum(temp.^2);

% evaluate the prior
logpriorbsig2 = - 0.5*N*log(6.2832) - 0.5*log(det(priorvar));
logpriorbsig2 = logpriorbsig2 - 0.5*(b - priorm)'/priorvar*(b - priorm);
logpriorbsig2 = logpriorbsig2 - gammaln(0.5*priorv) -0.5*priorv*log(2) + 0.5*priorv.*log(priors);
logpriorbsig2 = logpriorbsig2 - 0.5*(priorv+2)*log(sig2) - 0.5*priors/sig2;

end
