function [sig2, logpriorsig2] = drawsig2(u, priors, priorv)
% PURPOSE: Draw posterior error variance sig2 of a gaussian i.i.d variable
%           u~N(0,sig2)
% prior: p(sig2) = IG2(priors, priorv)
% Evaluate the prior at the drawn point sig2.
% This function is intended to be called as a part of a Gibbs sampler:

T = length(u);

% draw sig2
s = priors + sum(u.^2);
temp = randn(priorv + T, 1);
sig2 = s / sum(temp.^2);

% evaluate the prior
logpriorsig2 = - gammaln(0.5*priorv) -0.5*priorv*log(2) + 0.5*priorv.*log(priors);
logpriorsig2 = logpriorsig2 - 0.5*(priorv+2)*log(sig2) - 0.5*priors/sig2;

end
