clear all, close all

% yspec
% column 1: variable name in the dataset
% column 2: prior shares of variance of y explained by trend
% column 3: (rw) 1: trend rw, 0: trend rw with no drift, -1: trend i.i.d
% column 4: (irw,llt) expected number of periods before drift changes by 1ppt;
prior.yspec = {'yy', 0.5, 1, 1e3
    'in', 0.5, 1, 1e3;
    'im', 0.5, 1, 1e3;
    'ex', 0.5, 1, 1e3;
    'uu', 0.5, 0, 1e3;
    'cc', 0.5, 0, 1e3;
    'cu', 0.5, 0, 1e3;};
prior.yspec = prior.yspec(1:7,:);
prior.b.tightness = [0.5 0.5 0.5]; % tightness for the coefs of g in the factor model (starting from lead 1), specify at least 3
prior.trend.irw = true;
prior.trend.Hdname = 'c'; % only relevant for irw or llt trend
prior.trend.fixsig2d = false; % only relevant for irw or llt trend
% alternative priors for the law of motion of g
phi1.mean = 0.85; phi1.var = 0.05^2;
phi2.mean = [1.352; -0.508]; phi2.var = [0.0806, -0.0597; -0.0597, 0.0464];
phi20.mean = [0; 0]; phi20.var = 0.5*eye(2);
phi3.mean = [1.352; -0.508; 0]; phi3.var = blkdiag([0.0806, -0.0597; -0.0597, 0.0464],0.05^2);
prior.phi = phi2;
% pspec - name, PC coefficients of lagged p (ap), PC coefficients of g (ag)
prior.pspec = struct('name','pp', 'ap_mean',[0], 'ap_tightness',[0.1], 'ag_mean',[0 0.5 0], 'ag_tightness',[0.01 1 0.01]);
% xspec - observables mapped stochastically on state z that enters the inflation equation
%          specify the name, prior for the PC coefficients (az mean and tightness), 
%            prior for the LM: b.mean, b.std, sig2 (if x is observed sig2=frac (defaulting to 0.5), if not sig2=E(sig2))
%            prior for the ME: b.mean, b.std, sig2 (frac)
xpe = struct('name','pe','z_is_trend',1, 'ME_b_mean',[0 1], 'ME_b_std', [0.1 0.1], 'ME_sig2',0.25, 'LM_b_mean',[0 1], 'LM_b_std',[0.001 0.001], 'LM_sig2',0.5);
x00 = struct('name',[],'z_is_trend',1,'LM_b_mean',[0 1], 'LM_b_std',[0.001 0.001], 'LM_sig2', 1/1000);
prior.xspec = xpe;
% vspec - observable v mapped 1:1 on state q that enters the inflation equation
%          specify the name, prior for the PC coefficients, prior for the LM (b.mean, b.std, optionally sig2)
vpo = struct('name','po', 'aq_mean',zeros(1,4), 'aq_tightness',ones(1,4), 'LM_b_mean',[0 1 0], 'LM_b_std',[0.1 0.1 0.1]);
vpe = struct('name','pe', 'aq_mean',1, 'aq_tightness',0.5, 'LM_b_mean',[0.4 0.8], 'LM_b_std',[0.5 0.5]);
prior.vspec = {};
prior.sv = false;

clear phi xpe x00 vpo vpe

run