
% functions for time operations
yq2tq = @(y,q) y+q/4 - 1/8; % function useful for preparing the time axis for the plots
yq2datenum = @(yq) datenum(yq(1), yq(2)*3, (yq(2)==1)*31 + (yq(2)==2)*30 + (yq(2)==3)*30 + (yq(2)==4)*31);
tq2yq = @(tq) [floor(tq) round(4*(tq-floor(tq)+1/8))]; % convert time quarterly into [year quarter]
tq2datestr = @(tq) [num2str(floor(tq)) char(repmat(113,length(tq),1)) num2str(4*(tq-floor(tq)+1/8),'%1.0f')];
datenum2tq = @(dn) year(dn) + (month(dn)/3)/4 - 1/8;

% create time
time = yq2tq(1985,1):0.25:yq2tq(2020,4);

% load data
load '../data/datartd' %% real time series starting in 1985Q1 and ending in 2015Q4 - 157 vintages
load '../data/other' % pc, usd (per 1euro), pp16q4 for forecast evaluation, starting in 1985Q1

% transform data and put them into structure rtd
rtd.yy = 100*log(yy);
rtd.uu = uu;
rtd.pe = pe;
rtd.in = 100*log(in);
rtd.cc = cc;
rtd.cu = cu;
rtd.ex = 100*log(ex);
rtd.im = 100*log(im);
rtd.pp = [nan(1,size(pp,2)); 400*diff(log(pp))];
rtd.po = 100*log(po);
rtd.dpo = [nan(1,size(po,2)); 400*diff(log(po))];
rtd.pc = 100*log(pc);
rtd.dpc = [nan(1,size(pc,2)); 400*diff(log(pc))];
rtd.usd = -100*log(usd);
rtd.dusd = [nan(1,size(pc,2)); -400*diff(log(usd))];
rtd.pp16q4 = [nan; 400*diff(log(pp16q4))];
clear cc cu ex im in pe po pp uu yu yy pc usd pp16q4

% extract the series to use in the estimation
if isempty(prior.pspec)
    varnames = prior.yspec(:,1); prior.xspec = {}; prior.vspec = {};
elseif isempty(prior.yspec)
    varnames = {'pp'};
else
    varnames = [prior.pspec.name; prior.yspec(:,1)]; 
    if ~isempty(prior.xspec) && ~isempty(prior.xspec.name), varnames = [varnames; {prior.xspec.name}']; end
    if ~isempty(prior.vspec), varnames = [varnames; {prior.vspec(:).name}']; end
end
data = [];
for i = 1:length(varnames)
    data = [data rtd.(varnames{i})(1:124,end)]; % take the last vintage
end

prior.Ttr = 30; % length of the training sample
prior.S = find(time==yq2tq(2015,4)); % posterior uses data up to S
prior.H = 4; % compute forecasts for S(nowcast),S+1,...,S+H

disp(['training sample:   ' tq2datestr(time(1)) ' to ' tq2datestr(time(prior.Ttr))])
disp(['estimation sample: ' tq2datestr(time(prior.Ttr+1)) ' to ' tq2datestr(time(prior.S))])
disp(['forecast sample:   ' tq2datestr(time(prior.S+1)) ' to ' tq2datestr(time(prior.S+prior.H))])

% settings of the Gibbs sampler
gssettings.computemarglik = 1;
gssettings.waitbar = 1;
gssettings.nstepirf = 16;
gssettings.std0 = 0.1;
simul_type = 'test';
switch simul_type
    case 'test'
        gssettings.ndraws = 100; gssettings.burnin = 10; gssettings.saveevery = 1;
    case 'medium'
        gssettings.ndraws = 1000; gssettings.burnin = 10000; gssettings.saveevery = 40;
    case 'long'
        gssettings.ndraws = 10000; gssettings.burnin = 50000; gssettings.saveevery = 20;
end

true1 = rtd.pp16q4;

if isfield(prior,'estimate_function')
    [draws, prior, pdata, ydata, xdata, vdata] = prior.estimate_function(data, prior, gssettings, true1);
else
    [draws, prior, pdata, ydata, xdata, vdata] = dfmpc6d(data, prior, gssettings, true1);
end

