
% functions for time operations
yq2tq = @(y,q) y+q/4 - 1/8; % function useful for preparing the time axis for the plots
yq2datenum = @(yq) datenum(yq(1), yq(2)*3, (yq(2)==1)*31 + (yq(2)==2)*30 + (yq(2)==3)*30 + (yq(2)==4)*31);
tq2yq = @(tq) [floor(tq) round(4*(tq-floor(tq)+1/8))]; % convert time quarterly into [year quarter]
tq2datestr = @(tq) [num2str(floor(tq)) char(repmat(113,length(tq),1)) num2str(4*(tq-floor(tq)+1/8),'%1.0f')];
datenum2tq = @(dn) year(dn) + (month(dn)/3)/4 - 1/8;

% create time
time = yq2tq(1985,1):0.25:yq2tq(2020,4);

% load data
load '../data/datartd' %% real time series starting in 1985Q1 and ending in 2015Q4 - 157 vintages
load '../data/other' % pc, usd (per 1euro), pp16q4 for forecast evaluation, starting in 1985Q1

% transform data and put them into structure rtd
rtd.yy = 100*log(yy);
rtd.uu = uu;
rtd.pe = pe;
rtd.in = 100*log(in);
rtd.cc = cc;
rtd.cu = cu;
rtd.ex = 100*log(ex);
rtd.im = 100*log(im);
rtd.pp = [nan(1,size(pp,2)); 400*diff(log(pp))];
rtd.po = 100*log(po);
rtd.dpo = [nan(1,size(po,2)); 400*diff(log(po))];
rtd.pc = 100*log(pc);
rtd.dpc = [nan(1,size(pc,2)); 400*diff(log(pc))];
rtd.usd = -100*log(usd);
rtd.dusd = [nan(1,size(pc,2)); -400*diff(log(usd))];
rtd.pp16q4 = [nan; 400*diff(log(pp16q4))];
clear cc cu ex im in pe po pp uu yu yy pc usd pp16q4

% extract the series to use in the estimation
if isempty(prior.pspec)
    varnames = prior.yspec(:,1); prior.xspec = {}; prior.vspec = {};
elseif isempty(prior.yspec)
    varnames = {'pp'};
else
    varnames = [prior.pspec.name; prior.yspec(:,1)]; 
    if ~isempty(prior.xspec) && ~isempty(prior.xspec.name), varnames = [varnames; {prior.xspec.name}']; end
    if ~isempty(prior.vspec), varnames = [varnames; {prior.vspec(:).name}']; end
end

prior.Ttr = 30; % length of the training sample
prior.H = 4; 
prior.R = 4+1; % we will store the draws of the observables from S-R to S+H

% settings of the Gibbs sampler
gssettings.computemarglik = 0;
gssettings.waitbar = 1;
gssettings.nstepirf = 16;
gssettings.std0 = 0;
simul_type = 'medium';
switch simul_type
    case 'test'
        gssettings.ndraws = 100; gssettings.burnin = 10; gssettings.saveevery = 1;
    case 'medium'
        gssettings.ndraws = 1000; gssettings.burnin = 10000; gssettings.saveevery = 40;
    case 'long'
        gssettings.ndraws = 5000; gssettings.burnin = 50000; gssettings.saveevery = 40;
end

% specify vintages to use
nallsamples = size(rtd.(subsref(fieldnames(rtd),struct('type','{}','subs',{{1}}))),2);
vintages = [3:3:54 56:3:149 151:2:nallsamples]; %Take third month of the quarter, notice that Feb07 vintage still missing
nsamples = length(vintages);
timing_start = now;
disp(['start: ',datestr(timing_start,0), '; number of samples: ', num2str(nsamples)])

% allocate space for storage
S = nan(1,nsamples);
OGR = nan(size(rtd.pp,1)-prior.Ttr+prior.H, 7, nsamples);
fields_to_store = {'ag','obs','q_mean','q_var','q_true','q_med','q_err','q_logscores'};
if prior.sv, fields_to_store = [fields_to_store 'lBF']; end
drawsRall = cell2struct(cell(size(fields_to_store)), fields_to_store, 2);

% loop over vintages
for j = 1:nsamples
        
    disp(' '), disp(['sample number ' num2str(j) ' of ' num2str(nsamples)])
    jj = vintages(j);
    
    % last nonmissing observation of inflation + 1
    prior.S = find(~isnan(rtd.(prior.pspec.name)(:,jj)),1,'last')+1;
    S(j) = prior.S;
    
    % Real time data
    dataR = [];
    for i = 1:length(varnames)
        % take vintage jj
        dataR = [dataR rtd.(varnames{i})(1:124,jj)];
    end
        
    % evaluate forecast with vintage j+8 and with the final vintage
    true1 = rtd.(varnames{1})(:,[vintages(min(j+8,nsamples)) end]);
    % ... and with the later vintages
    true1 = [[true1; nan(size(rtd.pp16q4,1)-size(true1,1),size(true1,2))] rtd.pp16q4];
    
    disp(['training sample:   ' tq2datestr(time(1)) ' to ' tq2datestr(time(prior.Ttr))])
    disp(['estimation sample: ' tq2datestr(time(prior.Ttr+1)) ' to ' tq2datestr(time(prior.S))])
    disp(['forecast sample:   ' tq2datestr(time(prior.S+1)) ' to ' tq2datestr(time(prior.S+prior.H))])
    
    if isfield(prior,'estimate_function')
        [draws, prior, pdata, ydata, xdata, vdata] = prior.estimate_function(dataR, prior, gssettings, true1);
    else
        [draws, prior, pdata, ydata, xdata, vdata] = dfmpc6d(dataR, prior, gssettings, true1);
    end
        
    % store the output gap quantiles
    ogR = squeeze(quantile(draws.states(:,prior.igt,:),[0.05 0.10 0.16 0.5 0.84 0.90 0.95], 3));
    OGR(:,:,j) = [ogR; nan(size(dataR,1)-prior.Ttr+prior.H-size(ogR,1), size(ogR,2))];
    drawsRall(j) = orderfields(rmfield(draws, setdiff(fieldnames(draws),fields_to_store)),drawsRall);
    
    disp('progress report on recursive estimation')
    disp(timing_message(j, nsamples, timing_start)), disp(' ')
end

